﻿using System;
using System.Drawing;
using System.Windows.Forms;

//====================================================
// Описание работы классов и методов исходника на:
// www.interestprograms.ru
// Исходные коды программ и игр
// Автор исходных кодов Клочков Павел
//====================================================

namespace Screen1
{
    public partial class FormJokeScreen : Form
    {
        // Хранитель изначального размера окна.
        private Rectangle rectangleBounds;


        public FormJokeScreen()
        {
            InitializeComponent();
        }


        #region Методы

        private void CopyScreen()
        {

            // Получаем размеры экрана дисплея.
            int widthScreen = Screen.PrimaryScreen.Bounds.Width;
            int heightScreen = Screen.PrimaryScreen.Bounds.Height;


            // Создаем битовый массив (картинку) размером как у экрана монитора.
            var bitmapImage = new Bitmap(widthScreen, heightScreen);


            // Создаем поверхность рисования на созданном выше битовом массиве (картинке).
            var drawingSurface = Graphics.FromImage(bitmapImage);


            // Копируем изображение экрана в битовый массив.
            drawingSurface.CopyFromScreen(0, 0, 0, 0, bitmapImage.Size);


            // Созданную копию изображения экрана загружаем в PictureBox,
            // расположенный на поверхности окна программы-шутки.
            pictureScreenFake.Image = bitmapImage;
        }




        /// <summary>
        /// Остановка процесса шутки,
        /// и восстановление окна до первоначального вида.
        /// </summary>
        private void Reset()
        {
            // Останавливаем таймер
            timerProcess.Stop();

            // В первую очередь:
            // Восстанавливаем первоначальный вид
            this.FormBorderStyle = FormBorderStyle.FixedToolWindow;



            // Во вторую очередь:
            // Восстанавливаем размер и положение окна на экране
            this.Bounds = rectangleBounds;



            // Востанавливаем первоначальную картинку.
            pictureScreenFake.Image = Properties.Resources.улыбка;

            

            // Окно становится обычным в Z индексе
            this.TopMost = false;


            // Показываем кнопку
            buttonStart.Show();
        }

        #endregion


        #region События


        private void buttonStart_Click(object sender, EventArgs e)
        {
            // Запоминаем размеры окна.
            rectangleBounds = this.Bounds;


            // Скрываем окно программы-шутки
            this.Hide();



            // Скрываем кнопку.
            buttonStart.Hide();


            // Удаляем рамку вокруг окна.
            this.FormBorderStyle = FormBorderStyle.None;

            

            // Размер окна должен быть равен размеру экрана в пискелях. 
            this.Bounds = Screen.PrimaryScreen.Bounds;



            // Окно должно быть выше всех,
            // чтобы скрывать всё остальное.
            this.TopMost = true;

            
            // Запускаем таймер управления видимостью окна. 
            timerProcess.Start();

        }

        
        

        /// <summary>
        /// Если по развернутому окну сделать двойной щелчок,
        /// окно скроется и таймер запустится заново.
        /// Если перед двойным кликанием нажать клавишу Ctrl
        /// процесс остановится и окно возвратится к первоначальному виду.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void pictureScreenFake_DoubleClick(object sender, EventArgs e)
        {
            if (Control.ModifierKeys == Keys.Control)
            {
                Reset();
            }
            else
            {
                this.Visible = false;
                timerProcess.Start();
            }
        }



        private void timerProcess_Tick(object sender, EventArgs e)
        {
            if (this.Visible == false)
            {
                // Копируем экран.
                CopyScreen();

                // Показываем окно, заслоняя им весь экран.
                this.Show();
            }
            else
            {
                // На установленный промежуток времени скрываем окно.
                this.Hide();
            }


        }

        #endregion
    }
}
